@@ -58,10 +58,14 @@ class TaskModel:
             num_labels=kwargs['num_labels']
         )
         tokenizer = self.tokenizer.from_pretrained(self.model_path)
-        model = self.model_class.from_pretrained(
-            self.model_path,
-            config=config
-        )
+        unit_test = kwargs['num_labels']
+        if not unit_test:
+            model = self.model_class.from_pretrained(
+                self.model_path,
+                config=config
+            )
+        else:
+            model = None
         return config, tokenizer, model
 
 
@@ -100,7 +104,7 @@ class TaskModels:
 
     def task_model(self, model_path, model_task_type, tokenizer_name='default', language='cn',
                    ignore_not_exists=False) -> TaskModel:
-        model_cls = self._model_class(model_path, model_task_type, tokenizer_name, language)
+        model_cls = self._model_class(model_path, model_task_type, tokenizer_name, language, ignore_not_exists)
         if not model_cls and ignore_not_exists:
             return None
         return TaskModel(self.MODEL_TYPE, self.CONFIG, model_path,
