@@ -1,4 +1,4 @@
-from ai_harness.configuration import Arguments, configclass, field
+from ai_harness.configuration import Arguments, configclass, field, ComplexArguments
 from ai_harness import harnessutils as aiutils
 from ai_harness.fileutils import join_path, FileLineReader
 
